import { Exception } from "./Exception";
export interface EventLog {
    id: string;
    date: Date;
    result: "OK" | "WARN" | "ERROR";
    context: {
        [key: string]: string;
    };
    info: {
        [key: string]: string;
    };
    elapsedTime: number;
    action?: string;
    errorCode?: string;
}
/**
 * If eventLogger config is provided in non-DEV environment
 * All collected logs will automatically sent to {serverURL} every {sendingFrequency} second
 *
 * The request will be PUT to the server in the following format
 *      {events: LogEvent[]}
 */
export interface EventLoggerConfig {
    serverURL: string;
    sendingFrequency: number;
    maskedKeywords?: RegExp[];
}
export declare class EventLogger {
    private environmentContext;
    private uuidCounter;
    private logQueue;
    setContext(context: {
        [key: string]: string | (() => string);
    }): void;
    /**
     * Logger can log simple event (string type + parameter), or an exception
     * Declare function overload signatures in advance
     * Ref: http://www.typescriptlang.org/docs/handbook/functions.html#overloads
     */
    log(action: string, info?: {
        [key: string]: string;
    }): () => void;
    log(exception: Exception): () => void;
    private appendLog;
    private getUUID;
}
